define(["cilantro/define/conceptmanager"],function(a){var b=_.template('<div class="condition clearfix"><a href="#" class="remove"></a><%= condition %></div>'),c=$("#condition-list");c.bind("activate-criterion",function(b,d,e){c.children().removeClass("selected"),e.addClass("selected"),$.get(App.urls.criteria+d,function(b){a.show(b.viewset,e.data("constraint"))})});var d=function(a,c,d){var e=$(b(d));return e.data("constraint",a),e.find(".remove").click(function(){return App.hub.publish("CriteriaRemovedEvent",e),!1}),e.click(function(b){return e.trigger("activate-criterion",[a.concept_id,e]),!1}),e};return{Criteria:d}})