var __hasProp=Object.prototype.hasOwnProperty,__extends=function(a,b){function d(){this.constructor=a}for(var c in b)__hasProp.call(b,c)&&(a[c]=b[c]);return d.prototype=b.prototype,a.prototype=new d,a.__super__=b.prototype,a};define(["common/views/state","cilantro/utils/search"],function(a,b){var c,d,e,f;return d=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.ResultCollection),a.prototype.url=App.urls.criteria,a}(),e=function(){function b(){b.__super__.constructor.apply(this,arguments)}return __extends(b,a.View),b.prototype.template=_.template('<span class="name"><%= name %></span>                <br><span class="info"><%= domain.name %></span>'),b.prototype.events={click:"click"},b.prototype.render=function(){return this.el.html(this.template(this.model.toJSON())),this},b.prototype.click=function(){return App.hub.publish("concept/request",this.model.id),!1},b}(),c=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.InputView),a.prototype.el="#concept-search",a}(),f=function(){function a(){a.__super__.constructor.apply(this,arguments)}return __extends(a,b.ResultListView),a.prototype.el="#concept-search-results",a.prototype.viewClass=e,a.prototype.inputViewClass=c,a}(),{ResultCollection:d,ResultListView:f}})